/*
JRev: A JAVA MP3 Source Streamer
Copyright (C) 2000  Thomas Bohmbach, Jr.

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

package org.jrev;

/**
 * An interface that classes implement to provide
 * {@link StreamSource}s to the {@link JRev} engine.
 *
 * @author      pitboss
 * @version     1.0, 20000728
 * @since       1.0
 * @see         StreamSource
 * @see         JRev
 */
public interface Playlist
{
    /**
     * Returns the "current" <code>StreamSource</code>.  That is, the source
     * that is currently being played.  This is always the first method that a
     * <code>JRev</code> instance will call upon initialization to get the
     * first source that it should play.  This implies that a
     * <code>Playlist</code> should always be initialized in such a way that
     * the first call to this method returns the "first" source to play.
     *
     * @author      pitboss
     * @version     1.0, 20000728
     *
     * @return      the current <code>StreamSource</code>.  <code>null</code>
     *              should be returned if no source is available.
     */
    public StreamSource currentSource();

    /**
     * Returns the "next" <code>StreamSource</code>.  That is, the source
     * that should be played next, after the "current" source.  This method
     * is called by <code>JRev</code> when it has finished a source and is
     * ready for the next.
     *
     * @author      pitboss
     * @version     1.0, 20000728
     *
     * @return      the next <code>StreamSource</code>.  <code>null</code>
     *              should be returned if no source is available.
     */
    public StreamSource nextSource();
}
